==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebActiveStepChangedArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveStepChangedArgsDetailDescription } from "./WebActiveStepChangedArgsDetailDescription";
/**
 * @hidden
 */
var WebActiveStepChangedArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActiveStepChangedArgsDetailDescriptionMetadata, _super);
    function WebActiveStepChangedArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActiveStepChangedArgsDetailDescriptionMetadata.b = function (a) {
        if (WebActiveStepChangedArgsDetailDescriptionMetadata.a == null) {
            WebActiveStepChangedArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActiveStepChangedArgsDetailDescriptionMetadata.c(WebActiveStepChangedArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebActiveStepChangedArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebActiveStepChangedArgsDetailDescriptionMetadata.a);
    };
    WebActiveStepChangedArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActiveStepChangedArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("Index", "Number:double");
    };
    WebActiveStepChangedArgsDetailDescriptionMetadata.d = function (a) {
        WebActiveStepChangedArgsDetailDescriptionMetadata.b(a);
        a.ad("WebActiveStepChangedArgsDetail", function () { return new WebActiveStepChangedArgsDetailDescription(); });
        a.ac("WebActiveStepChangedArgsDetail", WebActiveStepChangedArgsDetailDescriptionMetadata.a);
    };
    WebActiveStepChangedArgsDetailDescriptionMetadata.$t = markType(WebActiveStepChangedArgsDetailDescriptionMetadata, 'WebActiveStepChangedArgsDetailDescriptionMetadata');
    WebActiveStepChangedArgsDetailDescriptionMetadata.a = null;
    return WebActiveStepChangedArgsDetailDescriptionMetadata;
}(Base));
export { WebActiveStepChangedArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebActiveStepChangedArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveStepChangedArgsDetailDescription } from "./WebActiveStepChangedArgsDetailDescription";
/**
 * @hidden
 */
var WebActiveStepChangedArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActiveStepChangedArgsDetailDescriptionMetadata, _super);
    function WebActiveStepChangedArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActiveStepChangedArgsDetailDescriptionMetadata.b = function (a) {
        if (WebActiveStepChangedArgsDetailDescriptionMetadata.a == null) {
            WebActiveStepChangedArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActiveStepChangedArgsDetailDescriptionMetadata.c(WebActiveStepChangedArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebActiveStepChangedArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebActiveStepChangedArgsDetailDescriptionMetadata.a);
    };
    WebActiveStepChangedArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActiveStepChangedArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Index", "Number:double");
    };
    WebActiveStepChangedArgsDetailDescriptionMetadata.d = function (a) {
        WebActiveStepChangedArgsDetailDescriptionMetadata.b(a);
        a.ae("WebActiveStepChangedArgsDetail", function () { return new WebActiveStepChangedArgsDetailDescription(); });
        a.ad("WebActiveStepChangedArgsDetail", WebActiveStepChangedArgsDetailDescriptionMetadata.a);
    };
    WebActiveStepChangedArgsDetailDescriptionMetadata.$t = markType(WebActiveStepChangedArgsDetailDescriptionMetadata, 'WebActiveStepChangedArgsDetailDescriptionMetadata');
    WebActiveStepChangedArgsDetailDescriptionMetadata.a = null;
    return WebActiveStepChangedArgsDetailDescriptionMetadata;
}(Base));
export { WebActiveStepChangedArgsDetailDescriptionMetadata };
